@@ -1,10 +1,10 @@
-export default function download_file(filename, data, binary = false) {
+export default function download_file({filename, data, mimeType}) {
     const link = document.createElement("a");
 
-    if (binary) {
+    if (data instanceof Blob) {
         link.setAttribute("href", URL.createObjectURL(data));
     } else {
-        link.setAttribute("href", "data:text/plain;base64," + data);
+        link.setAttribute("href", `data:${mimeType};base64,${data}`);
     }
 
     link.setAttribute("download", filename);
